import { AdEntity } from '@modules/ad/core/domain/ad.entity';
import { CreateAdProps, Frequency } from '@modules/ad/core/domain/ad.types';
import { PointProps } from '@modules/ad/core/domain/value-objects/point.value-object';

const originPointProps: PointProps = {
  lat: 48.689445,
  lon: 6.17651,
};
const destinationPointProps: PointProps = {
  lat: 48.8566,
  lon: 2.3522,
};

const createAdProps: CreateAdProps = {
  id: 'e8fe64b1-4c33-49e1-9f69-4db48b21df36',
  driver: true,
  passenger: true,
  fromDate: '2023-06-21',
  toDate: '2023-06-21',
  schedule: [
    {
      day: 3,
      time: '08:30',
      margin: 900,
    },
  ],
  frequency: Frequency.PUNCTUAL,
  seatsProposed: 3,
  seatsRequested: 1,
  strict: false,
  waypoints: [originPointProps, destinationPointProps],
  driverDistance: 23000,
  driverDuration: 900,
  passengerDistance: 23000,
  passengerDuration: 900,
  fwdAzimuth: 283,
  backAzimuth: 93,
  points: [],
};

describe('Ad entity create', () => {
  it('should create a new entity', async () => {
    const ad: AdEntity = AdEntity.create(createAdProps);
    expect(ad.id.length).toBe(36);
    expect(ad.getProps().schedule.length).toBe(1);
    expect(ad.getProps().schedule[0].day).toBe(3);
    expect(ad.getProps().schedule[0].time).toBe('08:30');
    expect(ad.getProps().driver).toBeTruthy();
    expect(ad.getProps().passenger).toBeTruthy();
    expect(ad.getProps().driverDistance).toBe(23000);
  });
});
