import { AdCreatedMessageHandler } from '@modules/ad/interface/message-handlers/ad-created.message-handler';
import { CommandBus } from '@nestjs/cqrs';
import { Test, TestingModule } from '@nestjs/testing';

const adCreatedMessage =
  '{"id":"4eb6a6af-ecfd-41c3-9118-473a507014d4","driver":"true","passenger":"true","frequency":"PUNCTUAL","fromDate":"2023-08-18","toDate":"2023-08-18","schedule":[{"day":"5","time":"10:00","margin":"900"}],"seatsProposed":"3","seatsRequested":"1","strict":"false","waypoints":[{"position":"0","houseNumber":"5","street":"rue de la monnaie","locality":"Nancy","postalCode":"54000","country":"France","lon":"48.689445","lat":"6.17651"},{"position":"1","locality":"Paris","postalCode":"75000","country":"France","lon":"48.8566","lat":"2.3522"}]}';

const mockCommandBus = {
  execute: jest.fn(),
};

describe('Ad Created Message Handler', () => {
  let adCreatedMessageHandler: AdCreatedMessageHandler;

  beforeAll(async () => {
    const module: TestingModule = await Test.createTestingModule({
      providers: [
        {
          provide: CommandBus,
          useValue: mockCommandBus,
        },
        AdCreatedMessageHandler,
      ],
    }).compile();

    adCreatedMessageHandler = module.get<AdCreatedMessageHandler>(
      AdCreatedMessageHandler,
    );
  });

  afterEach(async () => {
    jest.clearAllMocks();
  });

  it('should be defined', () => {
    expect(adCreatedMessageHandler).toBeDefined();
  });

  it('should create an ad', async () => {
    jest.spyOn(mockCommandBus, 'execute');
    await adCreatedMessageHandler.adCreated(adCreatedMessage);
    expect(mockCommandBus.execute).toHaveBeenCalledTimes(1);
  });
});
